@@ -9,12 +9,12 @@ from django.db import models
 from django.db.models.query import QuerySet
 from django.utils import timezone
 
+from imicusfat import __title__
+from imicusfat.utils import LoggerAddTag
+
 from allianceauth.eveonline.models import EveCharacter
 from allianceauth.services.hooks import get_extension_logger
 
-from . import __title__
-from .utils import LoggerAddTag
-
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -137,12 +137,19 @@ class IFatLinkType(SoftDeletionModel):
     """
 
     id = models.AutoField(primary_key=True)
-    name = models.CharField(max_length=254)
+
+    name = models.CharField(
+        max_length=254, help_text="Descriptive name of your fleet type"
+    )
+
     is_enabled = models.BooleanField(
         default=True,
         db_index=True,
     )
-    deleted_at = models.DateTimeField(blank=True, null=True)
+
+    deleted_at = models.DateTimeField(
+        blank=True, null=True, help_text="Has this been deleted?"
+    )
 
     def __str__(self):
         return "{} - {}".format(self.id, self.name)
@@ -154,7 +161,6 @@ class IFatLinkType(SoftDeletionModel):
 
         verbose_name = "FAT Link Type"
         verbose_name_plural = "FAT Link Types"
-        default_permissions = ()
 
 
 # IFatLink Model
@@ -163,13 +169,39 @@ class IFatLink(SoftDeletionModel):
     IFatLink
     """
 
-    ifattime = models.DateTimeField(default=timezone.now)
-    fleet = models.CharField(max_length=254, null=True)
-    hash = models.CharField(max_length=254)
-    creator = models.ForeignKey(User, on_delete=models.SET(get_sentinel_user))
-    deleted_at = models.DateTimeField(blank=True, null=True)
-    link_type = models.ForeignKey(IFatLinkType, on_delete=models.CASCADE, null=True)
-    is_esilink = models.BooleanField(default=False)
+    ifattime = models.DateTimeField(
+        default=timezone.now, help_text="When was this fatlink created"
+    )
+
+    fleet = models.CharField(
+        max_length=254,
+        null=True,
+        help_text="The fatlinks fleet name",
+    )
+
+    hash = models.CharField(max_length=254, help_text="The fatlinks hash")
+
+    creator = models.ForeignKey(
+        User,
+        on_delete=models.SET(get_sentinel_user),
+        help_text="Who created the fatlink?",
+    )
+
+    deleted_at = models.DateTimeField(
+        blank=True, null=True, help_text="Has been deleted or not"
+    )
+
+    link_type = models.ForeignKey(
+        IFatLinkType,
+        on_delete=models.CASCADE,
+        null=True,
+        help_text="The fatlinks fleet type, if it's set",
+    )
+
+    is_esilink = models.BooleanField(
+        default=False,
+        help_text="Whether this fatlink was created via ESI or not",
+    )
 
     def __str__(self):
         return self.hash[6:]
@@ -202,6 +234,14 @@ class ClickIFatDuration(models.Model):
     duration = models.PositiveIntegerField()
     fleet = models.ForeignKey(IFatLink, on_delete=models.CASCADE)
 
+    class Meta:
+        """
+        Meta
+        """
+
+        verbose_name = "FAT Duration"
+        verbose_name_plural = "FAT Durations"
+
 
 # IFAT Model
 class IFat(SoftDeletionModel):
@@ -209,11 +249,29 @@ class IFat(SoftDeletionModel):
     IFat
     """
 
-    character = models.ForeignKey(EveCharacter, on_delete=models.CASCADE)
-    ifatlink = models.ForeignKey(IFatLink, on_delete=models.CASCADE)
-    system = models.CharField(max_length=100, null=True)
-    shiptype = models.CharField(max_length=100, null=True)
-    deleted_at = models.DateTimeField(blank=True, null=True)
+    character = models.ForeignKey(
+        EveCharacter,
+        on_delete=models.CASCADE,
+        help_text="Character who registered this fat",
+    )
+
+    ifatlink = models.ForeignKey(
+        IFatLink,
+        on_delete=models.CASCADE,
+        help_text="The fatlink the character registered with",
+    )
+
+    system = models.CharField(
+        max_length=100, null=True, help_text="The system the character is in"
+    )
+
+    shiptype = models.CharField(
+        max_length=100, null=True, help_text="The ship the character was flying"
+    )
+
+    deleted_at = models.DateTimeField(
+        blank=True, null=True, help_text="Has been deleted or not"
+    )
 
     def __str__(self):
         return "{} - {}".format(self.ifatlink, self.character)
@@ -238,11 +296,23 @@ class ManualIFat(models.Model):
     ifatlink = models.ForeignKey(IFatLink, on_delete=models.CASCADE)
     character = models.ForeignKey(EveCharacter, on_delete=models.CASCADE)
 
+    created_at = models.DateTimeField(
+        blank=True, null=True, help_text="Time this FAT has been added manually"
+    )
+
     # Add property for getting the user for a character.
 
     def __str__(self):
         return "{} - {} ({})".format(self.ifatlink, self.character, self.creator)
 
+    class Meta:
+        """
+        Meta
+        """
+
+        verbose_name = "Manual FAT Log"
+        verbose_name_plural = "Manual FAT Logs"
+
 
 # DelLog Model
 class DelLog(models.Model):
@@ -276,4 +346,3 @@ class DelLog(models.Model):
 
         verbose_name = "Delete Log"
         verbose_name_plural = "Delete Logs"
-        default_permissions = ()
