@@ -6,10 +6,10 @@ providers
 
 from esi.clients import EsiClientProvider
 
-from allianceauth.services.hooks import get_extension_logger
+from imicusfat import __title__
+from imicusfat.utils import LoggerAddTag, get_swagger_spec_path
 
-from . import __title__
-from .utils import LoggerAddTag, get_swagger_spec_path
+from allianceauth.services.hooks import get_extension_logger
 
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
