@@ -19,6 +19,21 @@ from django.utils.crypto import get_random_string
 from esi.decorators import token_required
 from esi.models import Token
 
+from imicusfat import __title__
+from imicusfat.forms import FatLinkForm, ManualFatForm, ClickFatForm, FatLinkEditForm
+from imicusfat.models import (
+    IFat,
+    ClickIFatDuration,
+    IFatLink,
+    ManualIFat,
+    DelLog,
+    IFatLinkType,
+)
+from imicusfat.permissions import get_user_permissions
+from imicusfat.providers import esi
+from imicusfat.tasks import get_or_create_char, process_fats
+from imicusfat.utils import LoggerAddTag
+
 from allianceauth.authentication.decorators import permissions_required
 from allianceauth.authentication.models import CharacterOwnership
 from allianceauth.eveonline.models import (
@@ -29,14 +44,6 @@ from allianceauth.eveonline.models import (
 from allianceauth.eveonline.providers import provider
 from allianceauth.services.hooks import get_extension_logger
 
-from . import __title__
-from .forms import FatLinkForm, ManualFatForm, ClickFatForm, FatLinkEditForm
-from .models import IFat, ClickIFatDuration, IFatLink, ManualIFat, DelLog, IFatLinkType
-from .permissions import get_user_permissions
-from .providers import esi
-from .tasks import get_or_create_char, process_fats
-from .utils import LoggerAddTag
-
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -154,7 +161,9 @@ def stats(request, year=None):
         "data": data,
         "charstats": months,
         "year": year,
-        "current_year": datetime.now().year,
+        "year_current": datetime.now().year,
+        "year_prev": int(year) - 1,
+        "year_next": int(year) + 1,
         "permissions": permissions,
     }
 
@@ -164,7 +173,7 @@ def stats(request, year=None):
 
 
 @login_required()
-def stats_char(request, charid, month=None, year=None):
+def stats_char(request, charid, year=None, month=None):
     """
     character statistics view
     :param request:
@@ -266,7 +275,7 @@ def stats_char(request, charid, month=None, year=None):
 
 @login_required()
 @permissions_required(("imicusfat.stats_corp_own", "imicusfat.stats_corp_other"))
-def stats_corp(request, corpid, month=None, year=None):
+def stats_corp(request, corpid, year=None, month=None):
     """
     corp statistics view
     :param request:
@@ -279,6 +288,9 @@ def stats_corp(request, corpid, month=None, year=None):
     # get users permissions
     permissions = get_user_permissions(request.user)
 
+    if not year:
+        year = datetime.now().year
+
     # Check character has permission to view other corp stats
     if int(request.user.profile.main_character.corporation_id) != int(corpid):
         if not request.user.has_perm("imicusfat.stats_corp_other"):
@@ -292,8 +304,7 @@ def stats_corp(request, corpid, month=None, year=None):
     corp = EveCorporationInfo.objects.get(corporation_id=corpid)
     corp_name = corp.corporation_name
 
-    if not month and not year:
-        year = datetime.now().year
+    if not month:
         months = []
 
         for i in range(1, 13):
@@ -311,6 +322,9 @@ def stats_corp(request, corpid, month=None, year=None):
             "months": months,
             "corpid": corpid,
             "year": year,
+            "year_current": datetime.now().year,
+            "year_prev": int(year) - 1,
+            "year_next": int(year) + 1,
             "type": 0,
             "permissions": permissions,
         }
@@ -434,7 +448,7 @@ def stats_corp(request, corpid, month=None, year=None):
 
 @login_required()
 @permission_required("imicusfat.stats_corp_other")
-def stats_alliance(request, allianceid, month=None, year=None):
+def stats_alliance(request, allianceid, year=None, month=None):
     """
     fatlinks view
     :param request:
@@ -447,6 +461,9 @@ def stats_alliance(request, allianceid, month=None, year=None):
     # get users permissions
     permissions = get_user_permissions(request.user)
 
+    if not year:
+        year = datetime.now().year
+
     if allianceid == "000":
         allianceid = None
 
@@ -457,8 +474,7 @@ def stats_alliance(request, allianceid, month=None, year=None):
         ally = None
         alliance_name = "No Alliance"
 
-    if not month and not year:
-        year = datetime.now().year
+    if not month:
         months = []
 
         for i in range(1, 13):
@@ -476,6 +492,9 @@ def stats_alliance(request, allianceid, month=None, year=None):
             "months": months,
             "corpid": allianceid,
             "year": year,
+            "year_current": datetime.now().year,
+            "year_prev": int(year) - 1,
+            "year_next": int(year) + 1,
             "type": 1,
             "permissions": permissions,
         }
@@ -654,20 +673,23 @@ def stats_alliance(request, allianceid, month=None, year=None):
 
 
 @login_required()
-def links(request):
+def links(request, year=None):
     """
     fatlinks view
     :param request:
     :return:
     """
 
+    if year is None:
+        year = datetime.now().year
+
     msg = None
 
     if "msg" in request.session:
         msg = request.session.pop("msg")
 
     fatlinks = (
-        IFatLink.objects.all()
+        IFatLink.objects.filter(ifattime__year=year)
         .order_by("-ifattime")
         .annotate(number_of_fats=Count("ifat", filter=Q(ifat__deleted_at__isnull=True)))
     )
@@ -675,7 +697,15 @@ def links(request):
     # get users permissions
     permissions = get_user_permissions(request.user)
 
-    context = {"links": fatlinks, "msg": msg, "permissions": permissions}
+    context = {
+        "links": fatlinks,
+        "msg": msg,
+        "year": year,
+        "year_current": datetime.now().year,
+        "year_prev": int(year) - 1,
+        "year_next": int(year) + 1,
+        "permissions": permissions,
+    }
 
     logger.info("FAT link list called by %s", request.user)
 
@@ -1047,6 +1077,7 @@ def edit_link(request, hash=None):
             shiptype = manual_fat_form.cleaned_data["shiptype"]
             creator = request.user
             character = get_or_create_char(name=character_name)
+            created_at = timezone.now()
 
             if character is not None:
                 IFat(
@@ -1057,7 +1088,10 @@ def edit_link(request, hash=None):
                 ).save()
 
                 ManualIFat(
-                    ifatlink_id=link.pk, creator=creator, character=character
+                    ifatlink_id=link.pk,
+                    creator=creator,
+                    character=character,
+                    created_at=created_at,
                 ).save()
 
                 request.session["{}-task-code".format(hash)] = 3
@@ -1194,7 +1228,7 @@ def del_fat(request, hash, fat):
 
     fat.delete()
 
-    DelLog(remover=request.user, deltype=1, string=fat.__str__())
+    DelLog(remover=request.user, deltype=1, string=fat.__str__()).save()
     request.session["msg"] = [
         "success",
         "The FAT from link {0} has been successfully deleted.".format(hash),
